@@ -1,6 +1,7 @@
 import telebot
 from telebot import types
 import sys
+import webbrowser
 from io import BytesIO
 import requests
 from PIL import Image
@@ -361,4 +362,5 @@ def telegraph_article(address, v_type):
         )
 
         link_article = 'https://telegra.ph/{}'.format(response['path'])
-        print(link_article)
\ No newline at end of file
+        print(link_article)
+        webbrowser.open(link_article)
\ No newline at end of file
